@@ -28,7 +28,7 @@ from departments.utils.department_funcs import (
 )
 
 
-class DepartmentViewSet(object):
+class DepartmentControl(object):
 
     def __init__(self, organization_id: int):
         if not isinstance(organization_id, int):
